@@ -2,23 +2,21 @@
 #*                       qt-recordMyDesktop                                    *
 #*******************************************************************************
 #*                                                                             *
-#*           Copyright (C) 2007  John Varouhakis                               *
+#*           Copyright (C) 2007, 2008  John Varouhakis                         *
 #*                                                                             *
 #*                                                                             *
-#*  This program is free software; you can redistribute it and/or modify       *
-#*  it under the terms of the GNU General Public License as published by       *
-#*  the Free Software Foundation; either version 2 of the License, or          *
-#*  (at your option) any later version.                                        *
+#*   This program is free software: you can redistribute it and/or modify      *
+#*   it under the terms of the GNU General Public License as published by      *
+#*   the Free Software Foundation, either version 3 of the License, or         *
+#*   (at your option) any later version.                                       *
 #*                                                                             *
-#*  This program is distributed in the hope that it will be useful,            *
-#*  but WITHOUT ANY WARRANTY; without even the implied warranty of             *
-#*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
-#*  GNU General Public License for more details.                               *
-#*                                                                             *
-#*  You should have received a copy of the GNU General Public License          *
-#*  along with this program; if not, write to the Free Software                *
-#*  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA  *
+#*   This program is distributed in the hope that it will be useful,           *
+#*   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+#*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+#*   GNU General Public License for more details.                              *
 #*                                                                             *
+#*   You should have received a copy of the GNU General Public License         *
+#*   along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
 #*                                                                             *
 #*                                                                             *
 #*  For further information contact me at johnvarouhakis@gmail.com             *
@@ -116,7 +114,7 @@ class simpleWidget(object):
         self.NETABox.insertWidget(-1,self.advanced_button)
         self.NETABox.insertWidget(-1,self.tipLabel)
         style=QtGui.QApplication.style()
-        icon_rec_pxm=QtGui.QPixmap(os.path.join(rmdConfig.pixmapdir,"qt-recordmydesktop_record.png"))
+        icon_rec_pxm=QtGui.QPixmap(os.path.join(rmdConfig.pixmapdir,"media-record.svg"))
 
         self.win_button=QtGui.QPushButton(smplButtonStrings[1],self.window)
         self.start_button=QtGui.QPushButton(QtGui.QIcon(icon_rec_pxm),smplStrings['Record'],self.window)
